DioApiHandlerConfig class

Constructors

DioApiHandlerConfig({required String baseUrl(), String? token()?, Duration? connectTimeout, Duration? receiveTimeout, void onError(dynamic error, int? statusCode)?})

Properties

baseUrl String Function()
final
connectTimeout Duration?
final
hashCode int
The hash code for this object.
no setterinherited
onError → void Function(dynamic error, int? statusCode)?
final
receiveTimeout Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String? Function()?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited